@@ -26,7 +26,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_nginx_ver ($self) {
-    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{NGINX_VER};
+    return $self->cfg->{NGINX}->{NGINX_VER} || $ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{NGINX_VER};
 }
 
 # APP
@@ -121,7 +121,7 @@ around app_build => sub ( $orig, $self ) {
 
         # pcre
         P->http->get(
-            qq[http://netcologne.dl.sourceforge.net/project/pcre/pcre/@{[$ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER}]}/pcre-@{[$ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER}]}.tar.gz],
+            qq[http://netcologne.dl.sourceforge.net/project/pcre/pcre/@{[$ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER}]}/pcre-@{[$ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER}]}.tar.gz],
             buf_size    => 1,
             cv          => $cv,
             on_progress => 1,
@@ -170,7 +170,7 @@ around app_build => sub ( $orig, $self ) {
                 '--with-http_sub_module',
                 '--with-http_gzip_static_module',
                 '--with-http_perl_module',
-                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->get_dist('pcore-nginx')->cfg->{NGINX}->{PCRE_VER},
+                '--with-pcre=' . $build_dir . 'pcre-' . $ENV->dist('Pcore-Nginx')->cfg->{NGINX}->{PCRE_VER},
                 '--with-pcre-jit',
                 map { '--add-module=' . $build_dir . $module->{$_}->{path} } grep { $module->{$_}->{enabled} } keys $module->%*,
             );
